@@ -191,6 +191,9 @@ INVALIDPARAMETERVALUE_DUPLICATE = 'InvalidParameterValue.Duplicate'
 # 参数值存在重复。
 INVALIDPARAMETERVALUE_DUPLICATEPARA = 'InvalidParameterValue.DuplicatePara'
 
+# 本端地域和端地域重复。
+INVALIDPARAMETERVALUE_DUPLICATEREGION = 'InvalidParameterValue.DuplicateRegion'
+
 # 值超过上限。
 INVALIDPARAMETERVALUE_EIPBRANDWIDTHOUTINVALID = 'InvalidParameterValue.EIPBrandWidthOutInvalid'
 
@@ -392,13 +395,13 @@ INVALIDPARAMETERVALUE_TAGKEYNOTEXISTS = 'InvalidParameterValue.TagKeyNotExists'
 # 标签没有分配配额。
 INVALIDPARAMETERVALUE_TAGNOTALLOCATEDQUOTA = 'InvalidParameterValue.TagNotAllocatedQuota'
 
-# 该标签和值不存在。
+# 该标签不存在。
 INVALIDPARAMETERVALUE_TAGNOTEXISTED = 'InvalidParameterValue.TagNotExisted'
 
 # 不支持的标签。
 INVALIDPARAMETERVALUE_TAGNOTSUPPORTTAG = 'InvalidParameterValue.TagNotSupportTag'
 
-# '标签资源格式错误。
+# 标签资源格式错误。
 INVALIDPARAMETERVALUE_TAGRESOURCEFORMATERROR = 'InvalidParameterValue.TagResourceFormatError'
 
 # 标签时间戳超配。
@@ -410,6 +413,9 @@ INVALIDPARAMETERVALUE_TAGVALNOTEXISTS = 'InvalidParameterValue.TagValNotExists'
 # 无效参数值。参数值太长。
 INVALIDPARAMETERVALUE_TOOLONG = 'InvalidParameterValue.TooLong'
 
+# 流量包ID格式错误。
+INVALIDPARAMETERVALUE_TRAFFICPACKAGEID = 'InvalidParameterValue.TrafficPackageId'
+
 # 该流量包ID不合法。
 INVALIDPARAMETERVALUE_TRAFFICPACKAGEIDMALFORMED = 'InvalidParameterValue.TrafficPackageIdMalformed'
 
@@ -428,6 +434,15 @@ INVALIDPARAMETERVALUE_VPCCIDRCONFLICT = 'InvalidParameterValue.VpcCidrConflict'
 # 当前功能不支持此专线网关。
 INVALIDPARAMETERVALUE_VPGTYPENOTMATCH = 'InvalidParameterValue.VpgTypeNotMatch'
 
+# 当前BGP隧道网段：`%(key)s`和已有BGP隧道网段：`%(value)s`重叠。
+INVALIDPARAMETERVALUE_VPNCONNBGPTUNNELCIDRCONFLICT = 'InvalidParameterValue.VpnConnBgpTunnelCidrConflict'
+
+# BGP隧道网段必须为掩码为30的网段。
+INVALIDPARAMETERVALUE_VPNCONNBGPTUNNELCIDRMASK = 'InvalidParameterValue.VpnConnBgpTunnelCidrMask'
+
+# 云端或用户端BGP地址：`%(value)s`必须在BGP隧道网段`%(key)s`内。
+INVALIDPARAMETERVALUE_VPNCONNBGPTUNNELCIDRNOTSUPPORTED = 'InvalidParameterValue.VpnConnBgpTunnelCidrNotSupported'
+
 # 目的网段和当前VPN通道的CIDR冲突。
 INVALIDPARAMETERVALUE_VPNCONNCIDRCONFLICT = 'InvalidParameterValue.VpnConnCidrConflict'
 
@@ -554,6 +569,12 @@ LIMITEXCEEDED_TAGTAGSEXCEEDED = 'LimitExceeded.TagTagsExceeded'
 # 流量包配额超过限制。
 LIMITEXCEEDED_TRAFFICPACKAGEQUOTA = 'LimitExceeded.TrafficPackageQuota'
 
+# 有效的对等个数超过配额上限。
+LIMITEXCEEDED_VPCPEERAVALIMITEXCEEDED = 'LimitExceeded.VpcPeerAvaLimitExceeded'
+
+# 可创建的对等连接个数超过总上限。
+LIMITEXCEEDED_VPCPEERTOTALLIMITEXCEEDED = 'LimitExceeded.VpcPeerTotalLimitExceeded'
+
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
@@ -575,6 +596,9 @@ RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 # 网段资源不足。
 RESOURCEINSUFFICIENT_CIDRBLOCK = 'ResourceInsufficient.CidrBlock'
 
+# 指定实例类型已售罄。
+RESOURCEINSUFFICIENT_INSTANCE = 'ResourceInsufficient.Instance'
+
 # 子网IP资源不足, 无法分配IP。
 RESOURCEINSUFFICIENT_SUBNET = 'ResourceInsufficient.Subnet'
 
@@ -608,6 +632,9 @@ UNAUTHORIZEDOPERATION_NOREALNAMEAUTHENTICATION = 'UnauthorizedOperation.NoRealNa
 # 主IP不支持指定操作。
 UNAUTHORIZEDOPERATION_PRIMARYIP = 'UnauthorizedOperation.PrimaryIp'
 
+# 对等连接本端VPC与对端VPC存在CIDR冲突,或一端与已建立的对等连接某一端冲突。
+UNAUTHORIZEDOPERATION_VPCPEERCIDRCONFLICT = 'UnauthorizedOperation.VpcPeerCidrConflict'
+
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
 
@@ -746,6 +773,9 @@ UNSUPPORTEDOPERATION_ECMPWITHUSERROUTE = 'UnsupportedOperation.EcmpWithUserRoute
 # 当前地域不支持启用组播。
 UNSUPPORTEDOPERATION_ENABLEMULTICAST = 'UnsupportedOperation.EnableMulticast'
 
+# 终端节点和终端节点服务的CdcId不一致。
+UNSUPPORTEDOPERATION_ENDPOINTMISMATCHENDPOINTSERVICECDCID = 'UnsupportedOperation.EndPointMismatchEndPointServiceCdcId'
+
 # 终端节点服务本身不能是终端节点。
 UNSUPPORTEDOPERATION_ENDPOINTSERVICE = 'UnsupportedOperation.EndPointService'
 
@@ -758,6 +788,12 @@ UNSUPPORTEDOPERATION_FLOWLOGSNOTSUPPORTKOINSTANCEENI = 'UnsupportedOperation.Flo
 # 不支持创建流日志：当前弹性网卡未绑定实例。
 UNSUPPORTEDOPERATION_FLOWLOGSNOTSUPPORTNULLINSTANCEENI = 'UnsupportedOperation.FlowLogsNotSupportNullInstanceEni'
 
+# 指定的客户令牌已经被使用。
+UNSUPPORTEDOPERATION_IDEMPOTENTPARAMETERMISMATCH = 'UnsupportedOperation.IdempotentParameterMismatch'
+
+# 先前的幂等请求仍在处理中，请稍后重试。
+UNSUPPORTEDOPERATION_IDEMPOTENTPROCESSING = 'UnsupportedOperation.IdempotentProcessing'
+
 # 该种类型地址不支持此操作。
 UNSUPPORTEDOPERATION_INCORRECTADDRESSRESOURCETYPE = 'UnsupportedOperation.IncorrectAddressResourceType'
 
@@ -818,7 +854,7 @@ UNSUPPORTEDOPERATION_LOCKEDRESOURCES = 'UnsupportedOperation.LockedResources'
 # 账户不支持修改公网IP的该属性。
 UNSUPPORTEDOPERATION_MODIFYADDRESSATTRIBUTE = 'UnsupportedOperation.ModifyAddressAttribute'
 
-# VPC实例内部有帐号纬度的IPv6白名单，不支持关联多云联网。
+# VPC实例内部有账号纬度的IPv6白名单，不支持关联多云联网。
 UNSUPPORTEDOPERATION_MULTIPLEVPCNOTSUPPORTATTACHACCOUNTHASIPV6 = 'UnsupportedOperation.MultipleVpcNotSupportAttachAccountHasIpv6'
 
 # 资源互斥操作任务正在执行。
@@ -830,6 +866,9 @@ UNSUPPORTEDOPERATION_NATGATEWAYEIPNOTEXISTS = 'UnsupportedOperation.NatGatewayEi
 # NAT网关存在未解绑的IP。
 UNSUPPORTEDOPERATION_NATGATEWAYHADEIPUNASSOCIATE = 'UnsupportedOperation.NatGatewayHadEipUnassociate'
 
+# NAT网关已被封禁，不支持此操作。
+UNSUPPORTEDOPERATION_NATGATEWAYRESTRICTED = 'UnsupportedOperation.NatGatewayRestricted'
+
 # SNAT/DNAT转换规则所指定的内网IP已绑定了其他的规则，无法重复绑定。
 UNSUPPORTEDOPERATION_NATGATEWAYRULEPIPEXISTS = 'UnsupportedOperation.NatGatewayRulePipExists'
 
@@ -866,6 +905,9 @@ UNSUPPORTEDOPERATION_NOTSUPPORTATTACHEDGEANDCROSSBORDERINSTANCE = 'UnsupportedOp
 # 不支持删除默认路由表。
 UNSUPPORTEDOPERATION_NOTSUPPORTDELETEDEFAULTROUTETABLE = 'UnsupportedOperation.NotSupportDeleteDefaultRouteTable'
 
+# 公有云到黑石的对等连接不支持删除。
+UNSUPPORTEDOPERATION_NOTSUPPORTDELETEVPCBMPEER = 'UnsupportedOperation.NotSupportDeleteVpcBmPeer'
+
 # 该地址类型不支持释放操作。
 UNSUPPORTEDOPERATION_NOTSUPPORTEDADDRESSIPSCHARGETYPE = 'UnsupportedOperation.NotSupportedAddressIpsChargeType'
 
@@ -923,6 +965,9 @@ UNSUPPORTEDOPERATION_ROLENOTFOUND = 'UnsupportedOperation.RoleNotFound'
 # 路由表绑定了子网。
 UNSUPPORTEDOPERATION_ROUTETABLEHASSUBNETRULE = 'UnsupportedOperation.RouteTableHasSubnetRule'
 
+# SslVpnClientIds：`vpnc-20f9b3d7` 证书状态已启用或Client证书状态不可用，不支持启用证书。
+UNSUPPORTEDOPERATION_SSLCLIENTCERTALREADYENABLEORCERTABNORMAL = 'UnsupportedOperation.SSLClientCertAlreadyEnableOrCertAbnormal'
+
 # SSL客户端状态不可用，不支持下载
 UNSUPPORTEDOPERATION_SSLCLIENTCERTDISABLEUNSUPPORTEDDOWNLOADSSLCLIENTCERT = 'UnsupportedOperation.SSLClientCertDisableUnsupportedDownloadSSLClientCert'
 
@@ -1013,12 +1058,36 @@ UNSUPPORTEDOPERATION_VERSIONMISMATCH = 'UnsupportedOperation.VersionMismatch'
 # 资源不属于同一个VPC。
 UNSUPPORTEDOPERATION_VPCMISMATCH = 'UnsupportedOperation.VpcMismatch'
 
+# 对等连接已存在。
+UNSUPPORTEDOPERATION_VPCPEERALREADYEXIST = 'UnsupportedOperation.VpcPeerAlreadyExist'
+
+# VPC网段存在CIDR冲突。
+UNSUPPORTEDOPERATION_VPCPEERCIDRCONFLICT = 'UnsupportedOperation.VpcPeerCidrConflict'
+
+# 对等连接状态错误。
+UNSUPPORTEDOPERATION_VPCPEERINVALIDSTATECHANGE = 'UnsupportedOperation.VpcPeerInvalidStateChange'
+
+# 该账不能发起操作。
+UNSUPPORTEDOPERATION_VPCPEERPURVIEWERROR = 'UnsupportedOperation.VpcPeerPurviewError'
+
 # 当前通道为非可用状态，不支持该操作。
 UNSUPPORTEDOPERATION_VPNCONNINVALIDSTATE = 'UnsupportedOperation.VpnConnInvalidState'
 
+# SPD本端网段冲突，请检查后重试。
+UNSUPPORTEDOPERATION_VPNCONNSPDOVERLAP = 'UnsupportedOperation.VpnConnSPDOverlap'
+
 # VPC类型VPN网关必须携带VpcId。
 UNSUPPORTEDOPERATION_VPNGWVPCIDMUSTHAVE = 'UnsupportedOperation.VpnGwVpcIdMustHave'
 
+# VPN不支持BGP
+UNSUPPORTEDOPERATION_VPNUNSUPPORTEDBGP = 'UnsupportedOperation.VpnUnsupportedBgp'
+
+# 对端网关BGP ASN和已有的通道对端或云上VPN的BGP ASN相同。
+UNSUPPORTEDOPERATION_VPNUNSUPPORTEDBGPASNEQUAL = 'UnsupportedOperation.VpnUnsupportedBgpAsnEqual'
+
+# VPN未配置BGP ASN。
+UNSUPPORTEDOPERATION_VPNUNSUPPORTEDNOTEXISTBGPASN = 'UnsupportedOperation.VpnUnsupportedNotExistBgpAsn'
+
 # 指定资源在不同的可用区。
 UNSUPPORTEDOPERATION_ZONEMISMATCH = 'UnsupportedOperation.ZoneMismatch'
 
